
/*
Required add-on modules:
	xml_tab

Required input files:	
	cholera.dta
	meningitis_measles.dta

Output files:
	figure1.pdf
	figure2.pdf
	figure3.pdf
	figureS1.pdf
	Table1.xml
	Table2.txt
	TableS1.csv
	TableS2.xml
	TableS3.xml
*/

*********************
* Initialization
*********************

* Set this local equal to the folder location for this script, e.g., "C:/Users/name/myfolder/"
local workdir "C:\Users\jreif\Dropbox\Economics\Research\archive\Meningitis\analysis\replication/"

version 14
clear
adopath ++ "`workdir'ado"
set more off
set varabbrev off
tempfile t graph1 graph2

**********************
**** FIGURE 1 ********
**********************
	
use "`workdir'data/meningitis_measles.dta", clear

collapse (sum) cases report, by(year mening) fast
keep if year>=1980 & year<=2002

graph twoway ///
	(line report year if mening==1, lc(black) lp(dash) yaxis(1)) ///
	(line cases year if mening==1, lc(black) lp(solid) yaxis(2)) ///
	, title("(A) Meningitis", size(medium)) ///
	xtitle("", size(small)) xlabel(1980(5)2000, labs(small)) ///
	ytitle("Number of countries", axis(1) size(small)) ylabel(0(10)50, labs(small) axis(1)) ///
	ytitle("Reported cases (thousands)", axis(2) size(small)) ylabel(0(50)250, labs(small) axis(2)) ytick(none, axis(2)) ///
	xline(1988, lc(black) lp(dot)) xline(1996, lc(black) lp(dot)) ///
	legend(label(1 "Countries reporting (left y-axis)") label(2 "Total reported cases (right y-axis)") size(small) pos(11) ring(0) col(1)) ///
	saving(`graph1'.gph, replace)

graph twoway ///
	(line report year if mening==0, lc(black) lp(dash) yaxis(1)) ///
	(line cases year if mening==0, lc(black) lp(solid) yaxis(2)) ///
	, title("(B) Measles", size(medium)) ///
	xtitle("", size(small)) xlabel(1980(5)2000, labs(small)) ///
	ytitle("Number of countries", axis(1) size(small)) ylabel(0(10)50, labs(small) axis(1)) ytick(none, axis(1)) ///
	ytitle("Reported cases (thousands)", axis(2) size(small)) ylabel(0(250)2000, labs(small) axis(2)) ///
	xline(1988, lc(black) lp(dot)) xline(1996, lc(black) lp(dot)) ///
	legend(off) ///
	saving(`graph2'.gph, replace)

graph combine `graph1'.gph `graph2'.gph, col(2) b1title("Year", size(vsmall))
graph export "`workdir'results/figure1.pdf", replace

*************************
*** FIGURE 2            *
*************************

* Panel A
use "`workdir'data/meningitis_measles.dta", clear

collapse (sum) cases (count) report=cases , by(year men_belt mening) fast
keep if year>=1980 & year<=2002

graph twoway (line report year if men_belt == 0 & mening==1, lc(black) lp(solid)) ///
	(line report year if men_belt == 1 & mening==1, lc(black) lp(dash)) ///
	, title("(A) By location", size(medium)) ///
	b1title(" ", size(small)) xtitle("", size(small)) xlabel(1980(5)2000, labs(small)) ///
	l1title("Number of countries reporting", size(small)) ytitle("", size(small)) ylabel(0(5)25, labs(small)) ///
	xline(1988, lc(black) lp(dot)) xline(1996, lc(black) lp(dot)) ///
	legend(label(1 "Not meningitis belt") label(2 "Meningitis belt") size(vsmall) pos(7) ring(0) col(1)) ///
	saving(`graph1'.gph, replace)

* Panel B
use "`workdir'data/meningitis_measles.dta", clear

collapse (sum) cases (count) report=cases, by(year tier mening) fast
keep if year>=1980 & year<=2002

graph twoway (line report year if tier == 3 & mening==1, lc(black) lp(dot)) ///
	(line report year if tier == 2 & mening==1, lc(black) lp(dash)) ///
	(line report year if tier == 1 & mening==1, lc(black) lp(solid)) ///
	, title("(B) By historical reporting", size(medium)) ///
	b1title(" ", size(small)) xtitle("", size(small)) xlabel(1980(5)2000, labs(small)) ///
	l1title("Number of countries reporting", size(small)) ytitle("", size(small)) ylabel(0(5)25, labs(small)) ///
	xline(1988, lc(black) lp(dot)) xline(1996, lc(black) lp(dot)) ///
	legend(label(1 "Top tercile") label(2 "Middle tercile") label(3 "Bottom tercile") size(vsmall) pos(7) ring(0) col(1)) ///
	saving(`graph2'.gph, replace)

graph combine `graph1'.gph `graph2'.gph, ycommon col(2) b1title("Year", size(vsmall))
graph export "`workdir'results/figure2.pdf", replace


***********************
* FIGURE 3 *
***********************
use "`workdir'data/meningitis_measles.dta", clear

* Cote d'Ivoire, Dem Rep of Congo, Djibouti, Eq Guinea
keep if inlist(country_id,13,14,15,17)

sort country year
keep if mening==1
keep country country_id year report men_belt cases
keep if year>=1980 & year<=2002
replace cases = 0 if cases == .

graph twoway (line cases year if country_id == 13 & men_belt==1, lc(grey)) ///
	(line cases year if country_id == 14 & men_belt==1, lc(black) lp(dash)) ///
	, title("(A) Meningitis belt", size(medium))  ///
	xtitle("", size(small)) xlabel(1980(5)2000, labs(small)) ///
	ytitle("Reported cases (thousands)", size(small)) ylabel(0(2)8, labs(small)) ytick(none) ///
	xline(1989, lc(black) lp(dot)) xline(1996, lc(black) lp(dot)) ///
	legend(label(1 "Cote d'Ivoire") label(2 "Dem. Rep. of Congo") size(small) pos(11) ring(0) col(1)) ///
	saving(`graph1'.gph, replace)

graph twoway (line cases year if country_id == 15 & men_belt==0, lc(grey)) ///
	(line cases year if country_id == 17 & men_belt==0, lc(black) lp(dash)) ///
	, title("(B) Not meningitis belt", size(medium))  ///
	xtitle("", size(small)) xlabel(1980(5)2000, labs(small)) ///
	ytitle("Reported cases (thousands)", size(small)) ylabel(0(.02).08, labs(small)) ytick(none) ///
	xline(1989, lc(black) lp(dot)) xline(1996, lc(black) lp(dot)) ///
	legend(label(1 "Djibouti") label(2 "Equatorial Guinea") size(small) pos(11) ring(0) col(1)) ///
	saving(`graph2'.gph, replace)

graph combine `graph1'.gph `graph2'.gph, col(2) b1title("Year", size(vsmall))
graph export "`workdir'results/figure3.pdf", replace

********************
****** TABLE 1 *****
********************
	
use "`workdir'data/meningitis_measles.dta", clear

* Prep sample: Measles data begins in 1980
keep if year>=1980
drop if inlist(year,1988,1996)
	
* Gen change in reporting and country indicators
bysort mening country_id (year): gen drep = report[_n] - report[_n-1]
tab country_id, g(c)
local if "if year <= 2002"
sort country_id year

* Regresson results for meningitis, measles, and the relative difference.  
reg drep period2 period3 c1-c54 `if' & mening==1, cl(country_id)		
estimates store meningitis
reg drep period2 period3 c1-c54 `if' & mening==0, cl(country_id)
estimates store measles
reg drep period2 period3 mening period2_m period3_m c1-c54 `if' & inlist(mening,0,1), cl(country_id)
estimates store relative	

* Regresson results by percent muslim
gen muslim = percentmuslim08>=1
forval j = 1/3 {
	gen period`j'_muslim = period`j' * muslim 
}

reg drep period2 period3 c1-c54 `if' & mening==1 & muslim==1, cl(country_id)		
estimates store muslim
reg drep period2 period3 c1-c54 `if' & mening==1 & muslim==0, cl(country_id)
estimates store nonmuslim

xml_tab meningitis measles relative muslim nonmuslim, save("`workdir'results/Table1.xml") replace keep(_cons period2 period3 mening period2_m period3_m) below sheet("Report_indiv_reg") stats(N r2)

********************
****** TABLE 2 *****
********************
		
use "`workdir'data/meningitis_measles.dta", clear

replace report = report*100
gen men_belt_perc = men_belt*100 
replace totalpop08 = totalpop08/1000000

ren totalpop08 pop08
ren percentmuslim08 muslim
ren aveRpre pctrpt
ren avepre rptcases

log using "`workdir'results/Table2.txt", text replace
di "Column 2 (muslim) in this table differs from the one in the published paper. This table reports the correct numbers."
tabstat pop08 muslim pctrpt rptcases if year==1970, by(men_belt) c(v) s(mean sd) f(%6.2f)
log close	

* Summary statistics: mean, sd
*   by categories of: men_belt (==1 if in Meningitis Belt)

* men_belt |  total~08  perce~08   aveRpre    avepre
* ---------+----------------------------------------
       * 0 |     12.21     32.40     64.94      0.30
*          |     17.58     39.40     30.66      0.50
* ---------+----------------------------------------
*        1 |     26.68     48.57     82.31      1.37
*          |     34.11     31.02     21.24      1.88
* ---------+----------------------------------------
*    Total |     17.84     38.69     71.69      0.72
*          |     26.15     37.08     28.57      1.33
* --------------------------------------------------



********************
* Table S 1
********************
use "`workdir'data/meningitis_measles.dta", clear

keep if mening==1 & year==1970
replace totalpop08 = totalpop08 / 1000

preserve
	keep if men_belt==1
	sort country
	keep country totalpop08 percentmuslim08 tier
	gen mergevar = _n
	save "`t'", replace
restore

keep if men_belt==0
sort country
keep country totalpop08 percentmuslim08 tier
foreach v in country totalpop08 percentmuslim08 tier {
	ren `v' `v'_not_in_mb
}
gen mergevar = _n
merge 1:1 mergevar using "`t'", assert(master match) nogenerate
drop mergevar
outsheet using "`workdir'results/TableS1.csv", comma replace

********************
* Table S 3
********************
use "`workdir'data/meningitis_measles.dta", clear

* Prep sample: Measles data begins in 1980
keep if year>=1980
drop if inlist(year,1988,1996)
	
* Gen change in reporting and country indicators
bysort mening country_id (year): gen drep = report[_n] - report[_n-2]
tab country_id, g(c)

local if "if year <= 2002"

sort country_id year
reg drep period2 period3 c1-c54 `if' & mening==1, cl(country_id)
estimates store meningitis
reg drep period2 period3 c1-c54 `if' & mening==0, cl(country_id)
estimates store measles
reg drep period2 period3 mening period2_m period3_m c1-c54 `if' & inlist(mening,0,1), cl(country_id)
estimates store trend3
xml_tab meningitis measles trend3, save("`workdir'results/TableS3.xml") replace keep(_cons period2 period3 mening period2_m period3_m) below sheet("Report_indiv_reg") stats(N r2)


*************************
***    Cholera (Figure S 1 and Table S 2)  *
*************************

use "`workdir'data/meningitis_measles.dta", clear
keep if mening==1 & year>=1970 & year<=2002
append using "`workdir'data/cholera.dta"
keep if year<=2002
preserve

* Figure S1
collapse (sum) cases (count) report=cases (median)  numcountriesreport_yr, by(year mening)

graph twoway ///
	(line report year if mening==1, lc(black) lp(dash) yaxis(1)) ///
	(line cases year if mening==1, lc(black) lp(solid) yaxis(2)) ///
	, title("(A) Meningitis", size(medium)) ///
	xtitle("", size(small)) xlabel(1970(5)2000, labs(small)) ///
	ytitle("Number of countries", axis(1) size(small)) ylabel(0(10)50, labs(small) axis(1)) ///
	ytitle("Reported cases (thousands)", axis(2) size(small)) ylabel(0(50)250, labs(small) axis(2)) ytick(none, axis(2)) ///
	xline(1988, lc(black) lp(dot)) xline(1995, lc(black) lp(dot)) ///
	legend(label(1 "Countries reporting (left y-axis)") label(2 "Total reported cases (right y-axis)") size(small) pos(11) ring(0) col(1)) ///
	saving(`graph1'.gph, replace)


	graph twoway ///
	(line report year if mening==0, lc(black) lp(dash) yaxis(1)) ///
	(line cases year if mening==0, lc(black) lp(solid) yaxis(2)) ///
	, title("(B) Cholera", size(medium)) ///
	xtitle("", size(small)) xlabel(1970(5)2000, labs(small)) ///
	ytitle("Number of countries", axis(1) size(small)) ylabel(0(10)50, labs(small) axis(1)) ytick(none, axis(1)) ///
	ytitle("Reported cases (thousands)", axis(2) size(small)) ylabel(0(250)2000, labs(small) axis(2)) ///
	xline(1988, lc(black) lp(dot)) xline(1995, lc(black) lp(dot)) ///
	legend(off) ///
	saving(`graph2'.gph, replace)

graph combine `graph1'.gph `graph2'.gph, col(2) ycommon b1title("Year", size(vsmall))
graph export "`workdir'results/figureS1.pdf", replace

restore

* Table S2
bysort mening country (year): gen drep = report[_n] - report[_n-1]
tab country, g(c)

local if "if year <= 2002"
sort country_id year
reg drep period2 period3 c1-c54 `if' & mening==1, cl(country)
estimates store meningitis
reg drep period2 period3 c1-c54 `if' & mening==0, cl(country)
estimates store cholera
reg drep period2 period3 mening period2_m period3_m c1-c54 `if' & inlist(mening,0,1), cl(country)
estimates store trend3
xml_tab meningitis cholera trend3, save("`workdir'results/TableS2.xml") replace keep(_cons period2 period3 mening period2_m period3_m) below sheet("Report_indiv_reg") stats(N r2)

** EOF
